<h1> BOJ_maker </h1>

Setting up bothering BOJ problems all at once.

번거로운 백준 문제 셋팅을 한번에 해줍니다.



<h2>Installation</h2>

```$ pip install bojmaker``` 



<h3> How to use </h3>

```$ bojmaker 1111```




- 어디서든 bojmaker <문항 번호> 만 입력하면
  - 문제 번호_문제 이름 으로 폴더 생성
  - sol1.py/cpp/java 파일 생성
  - input.txt 파일 생성 및 예제 입력
  - 해당 문제 백준 링크 출력



<h3> New Feature </h3>

- version 1.3
  - acmicpc 사이트의 봇 감지 우회 설정

- version 1.2
  - VS Code에서 Python 파일이 input.txt를 읽어올 수  경로 수정

- version 1.1
  - c++, java 파일 생성 추가

<h3> Notice </h3>

- PyCharm 환경에서는 실행 후 디렉토리 목록 아무데나 클릭 해주시면 폴더 생성이 반영됩니다~!

- 일부 문제에서 input.txt 생성시에 공백이 추가되는 현상이 있습니다.
  인풋 데이터 다루는 중에 오류가 나신다면 파일을 한번만 확인해주세요!

<h3> Thanks To </h3>



<h4>tae young Yu (neo@hphk.kr)</h4>



<h3> SSAFY 5기 화이팅~!! </h3>
<h4> feedback : kkokko-hero@hanmail.net </h4>
